@@ -103,7 +103,7 @@ if($file == 'gs_phonebook.xml') {
 	exit;
 } elseif(($file == 'ring1.bin') || ($file == 'ring2.bin') || ($file == 'ring3.bin')) {
 	$conn = pg_pconnect($dsn);
-	$query = sprintf("SELECT value FROM config WHERE key = '%s' AND uid = (SELECT id FROM users WHERE gshostname = '%s')",
+	$query = sprintf("SELECT value FROM config WHERE key = 'general_%s' AND uid = (SELECT id FROM users WHERE gshostname = '%s')",
 			$file, pg_escape_string($_SERVER['REMOTE_ADDR']));
 	$result = pg_query($query);
 	if(pg_num_rows($result)) {
