@@ -1,6 +1,17 @@
 <?php
 require("index.common.php");
 
+function get_logininfo() {
+	$html = sprintf("%s (%s): %s @ %s",
+			$_SESSION['username'],
+			$_SESSION['ext'],
+			$_SESSION['phone'],
+			$_SESSION['gshostname']);
+	return $html;
+}
+
+update_blf();
+
 echo '<?xml version="1.0" encoding="UTF-8"?>'
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
@@ -14,7 +25,7 @@ echo '<?xml version="1.0" encoding="UTF-8"?>'
 	</head> 
 	<body> 
 		<div id='logininfo' class='logininfo'><?=get_logininfo()?></div>
-		<h1><?=_("GS/* phonebook")?> v0.3</h1>
+		<h1><?=_("GS/* phonebook")?> v0.4</h1>
 		<ul class="menu" id='menu'>
 			<!--<li><?=_("Search")?>: <input type="text" name="searchbox" id="searchbox" size="20" onkeyup="searchFunc(document.getElementById('searchbox').value);"/></li>-->
 			<li><?=_("Search")?>: <input type="text" name="searchbox" id="searchbox" size="20" onkeyup="OnKeyRequestBuffer.modified('searchbox');"/></li>
@@ -26,10 +37,12 @@ echo '<?xml version="1.0" encoding="UTF-8"?>'
 			<?php } ?>
 			<li><a href="index.php?logout=1"><?=_("Logout")?></a></li>
 		</ul>
+		<div class="blflist" id="blflist"><?=html_blf()?></div>
 		<ul class="submenu" id='submenu'></ul>
 		<div class="callinfo" id="callinfo"></div>
 		<div class="content" id="content">
 		<?php
+			require_once("phonebook.php");
 			$pb = new phonebook();
 			print $pb->get_list("");
 		?>
