@@ -1,5 +1,11 @@
 <?php
-echo '<?xml version="1.0" encoding="UTF-8"?>'
+echo '<?xml version="1.0" encoding="UTF-8"?>';
+
+if(!isset($error))
+	$error = $_REQUEST['error'];
+
+$error = htmlspecialchars($error);
+
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
@@ -7,11 +13,11 @@ echo '<?xml version="1.0" encoding="UTF-8"?>'
 		<meta http-equiv="content-type" content="application/xhtml+xml; charset=UTF-8" />
 		<title><?=_("Asterisk GS Phonebook");?></title> 
 	</head> 
-	<body> 
+	<body onload='document.getElementById("username").focus()'> 
 		<div class='warning'><?=htmlspecialchars($error)?></div>
 		<form action='index.php' method='post'>
 		<div class='editlabel'><?=_("Username")?>:</div>
-		<input class='editlogin' type='text' name='username'><br/>
+		<input class='editlogin' type='text' name='username' id='username'><br/>
 		<div class='editlabel'><?=_("Password")?>:</div>
 		<input class='editlogin' type='password' name='password'><br/>
 		<div class='editbuttons'><input type='submit' value='<?=_("Login")?>'></div>
