@@ -39,7 +39,7 @@ class phonebook extends listobj {
 		$html .= "<input class='editlastname' type='text' name='phonenumber' value='" . $entry['phonenumber'] . "'/><br/>\n";
 		$html .= "<div class='editlabel'>" . _("Group") . ":</div>";
 		$html .= "<select name='gid' class='editgroup'>";
-		$defaultgid = get_config_value($_SESSION['uid'], 'defaultgid');
+		$defaultgid = get_config_value($_SESSION['uid'], 'general_defaultgid');
 		$result = pg_query("SELECT id, groupname FROM groups WHERE " . $this->get_permissionCond("id"));
 		$result = pg_fetch_all($result);
 		if($result)
